@@ -1,5 +1,6 @@
 import sys
 import os
+import simpleweb.utils
 
 def main():
 	command = "run"
@@ -20,9 +21,11 @@ def main():
 		func = vars(module)[command]
 		name = "%s %s" % (name, command)
 	except ImportError, e:
-		return "Error loading the <%s> plugin :\n\t%s\n" % (command, e)
+		simpleweb.utils.msg_err("Error loading the plugin : %s" % (e))
+		return
 	except KeyError, e:
-		return "Function %s is not defined in plugin module %s\n" % (command, command)
+		simpleweb.utils.msg_err("Function %s is not defined in plugin module %s" % (command, command))
+		return
 
 	func(name, args)
 
