@@ -9,10 +9,11 @@ def help(name, args):
 		try:
 			plugins = __import__('simpleweb.admin.plugins', {}, {}, 'plugins')
 		except ImportError, e:
-			sys.stderr.write("Failed to import simpleweb.admin.plugins. Details below:\n\t%s\n" % (e))
+			simpleweb.utils.msg_err("Failed to import simpleweb.admin.plugins: %s" % (e))
+			sys.exit()
 		else:
 			for i in plugins.__all__:
-				print "  %s" % (i)
+				print "  %s" % (i.replace('_', '-'))
 			print "  help"
 			print "  help [command]"
 
@@ -21,6 +22,6 @@ def help(name, args):
 		try:
 			module = __import__('simpleweb.admin.plugins.%s' % (command), {}, {}, command)
 		except ImportError:
-			sys.stderr.write("Command '%s' is not implemented\n" % (command))
+			simpleweb.utils.msg_err("Command '%s' is not implemented" % (command))
 		else:
 			sys.stdout.write("%s\n" % (getattr(module, command).__doc__))
