@@ -9,7 +9,7 @@ in the internal development web server
 	"""
 
 	if len(args) > 0:
-		simpleweb.utils.msg_err("RUN takes no arguments")
+		simpleweb.utils.msg_err("'%s' takes no arguments" % (name))
 		sys.exit(0)
 
 	simpleweb.run()
