@@ -1,4 +1,4 @@
-import selector,yaro
+from simpleweb.extlib import selector,yaro
 import simpleweb.utils
 
 class wrapper(yaro.Yaro):
@@ -28,7 +28,7 @@ class wrapper(yaro.Yaro):
 			return yaro.util.FileWrapper(body)
 
 class Urls(object):
-	def __init__(self, **kw):
+	def __init__(self):
 		self.urls = selector.Selector(wrap=wrapper)
 		self.urlmap = []
 
@@ -37,7 +37,11 @@ class Urls(object):
 
 	def _setup(self):
 		for url, controller in self.urlmap:
-			method_dict = simpleweb.utils.get_methods_dict(controller, ['GET', 'POST', 'PUT', 'DELETE'])
+			try:
+				method_dict = simpleweb.utils.get_methods_dict(controller, ['GET', 'POST', 'PUT', 'DELETE'])
+			except ImportError, e:
+				simpleweb.utils.msg_warn(str(e))
+				continue
 			self.urls.add(url, method_dict)
 
 	def geturls(self):
