@@ -14,7 +14,7 @@ class Config(object):
 			module = __import__(conf_file)
 			self.working_directory = os.getcwd()
 		except ImportError, e:
-			sys.stderr.write("Could not successfully import config.py. Details Below:\n\t%s\n" % (e))
+			simpleweb.utils.msg_err("Could not successfully import config.py : %s" % (e))
 			sys.exit(1)
 		else:
 			var_list = (v for v in dir(module) if not v.startswith('__'))
