@@ -22,22 +22,20 @@ def from_import(m, try_class=True):
 		#try to do from package import module
 		try:
 			r = __import__(m, {}, {}, [module])
-		except ImportError, e:
+		except ImportError:
 			#if import fails, we'll believe its a class
 			#and then try to back up the import path, and
 			#import the module there, and get the class as an
 			#attribute of the module. All this only if 'try_class' is 
 			# True
 			if not try_class:
-				sys.stderr.write("Failed to import '%s'. Details Below:\n\t%s\n" % (m, e))
-				sys.exit(1)
+				raise
 			else:
 				_module = from_import(package, try_class=False)
 				try:
 					return getattr(_module, module) #if the previous works, then module is a class in _module
 				except AttributeError:
-					sys.stderr.write("Failed to import '%s'. '%s' not found in '%s'\n" % (m, module, package))
-					sys.exit(1)
+					raise ImportError("Failed to import '%s'. '%s' not found in '%s'" % (m, module, package))
 		else: 
 			#if the import succeeds, return the module
 			return r
@@ -73,3 +71,17 @@ def get_methods_dict(m, list_of_methods):
 			method_dict[f.func_name] = f
 
 	return method_dict
+
+def optional_dependency_err(subsystem, dependency):
+	msg_err("Cannot initialize %s. %s must be properly installed first." % (subsystem, dependency))
+	sys.exit()
+
+def msg_info(msg):
+	sys.stdout.write("=> %s\n" %(msg))
+
+def msg_err(msg):
+	sys.stderr.write("!! %s\n" %(msg))
+
+def msg_warn(msg):
+	sys.stderr.write("** %s\n" %(msg))
+
